@@ -1,8 +1,9 @@
 \r mysql
-INSERT INTO user ( host, user, password )
-   VALUES (
+INSERT INTO 
+   user ( host, user, password )
+VALUES (
       'localhost',
       'hordemgr',
       password( 'hordemgr' )
-      );
+);
 
